@@ -20,61 +20,88 @@ administration and serving of these assets.
 
 =head2 auth
 
-Permission control for mojomojo pages.
+Return whether the current user has attachment manipulation rights (upload/delete).
 
 =cut
 
-sub auth : Private {
+sub auth :Private {
     my ( $self, $c ) = @_;
 
     my $perms =
         $c->check_permissions( $c->stash->{'path'},
         ( $c->user_exists ? $c->user->obj : undef ) );
-    if ( $perms->{'attachment'} ) {
-        return 1;
-    }
+    return $perms->{'attachment'}
+}
 
+=head2 unauthorized
+
+Private action to return a 403 with an explanatory template.
+
+=cut
+
+sub unauthorized :Private {
+    my ( $self, $c, $operation ) = @_;
     $c->stash->{template} = 'message.tt';
-    $c->stash->{message}  = $c->loc('You do not have permissions to edit attachments for this page');
-    return 0;
+    $c->stash->{message}  = $c->loc('You do not have permissions to x attachments for this page', $operation);
+    $c->response->status(403);  # 403 Forbidden
 }
 
 =head2 attachments
 
-main attachment screen.  Handles uploading of new attachments.
+Main attachment screen.  Handles uploading of new attachments.
 
 =cut
 
 sub attachments : Global {
     my ( $self, $c ) = @_;
 
-    return unless $c->check_view_permission;
+    $c->detach('unauthorized', ['view']) if not $c->check_view_permission;
 
     $c->stash->{template} = 'page/attachments.tt';
-    $c->forward('check_file');
 }
 
+=head2 list
+
+Display the list of attachments if the user has view permissions.
+
+B<template>: F<attachments/list.tt>
+
+=cut
+sub list : Local {
+    my ( $self, $c ) = @_;
+
+    $c->detach('unauthorized', ['view']) if not $c->check_view_permission;
+
+    $c->stash->{template}='attachments/list.tt';
+}
+
+
 sub plain_upload : Global {
     my ( $self, $c ) = @_;
-    $c->forward('auth');
+    $c->detach('unauthorized', ['upload']) if not $c->forward('auth');
     $c->forward('check_file');
 }
 
+=head2 check_file
+
+Check if the file(s) uploaded could be added to the Attachment table.
+
+=cut
 sub check_file : Private  {
     my ($self,$c)=@_;
     my $page = $c->stash->{page};
     if ( my $file = $c->req->params->{file} ) {
         my $upload = $c->request->upload('file');
-        my (@att) =
+        my (@att) =  # an array is returned if a ZIP upload was unpacked
             $c->model("DBIC::Attachment")
-            ->create_from_file( $page, $file, $upload->tempname, $c->path_to('/') );
+            ->create_from_file( $page, $file, $upload->tempname );
         if ( !@att ) {
             $c->stash->{template} = 'message.tt';
-            $c->stash->{message}  = $c->loc("Could not create attachment from x",$file);
+            $c->stash->{message}  = $c->loc("Could not create attachment from x", $file);
         }
 
         my $redirect_uri = $c->uri_for('attachments', {plain => $c->req->params->{plain}});
-        $c->res->redirect($redirect_uri)
+        $c->res->redirect($redirect_uri)  # TODO weird condition. This should be an else to the 'if' above
             unless defined $c->stash->{template} && $c->stash->{template} eq 'message.tt';
     }
 }
@@ -98,12 +125,15 @@ sub flash_upload : Local {
     $c->res->body('0');
 }
 
-sub list : Local {
+sub attachment : Chained CaptureArgs(1) {
+    my ( $self, $c, $att ) = @_;
+    $c->stash->{att} = $c->model("DBIC::Attachment")->find($att);
+    $c->detach('default') if not ( $c->stash->{att} );
+}
+
+sub defaultaction : PathPart('') Chained('attachment') Args(0) {
     my ( $self, $c ) = @_;
-
-    return unless $c->check_view_permission;
-
-    $c->stash->{template}='attachments/list.tt';
+    $c->forward('view');
 }
 
 =head2 default
@@ -114,17 +144,6 @@ an attachment id.
 
 =cut
 
-sub attachment : Chained CaptureArgs(1) {
-    my ( $self, $c, $att ) = @_;
-    $c->stash->{att} = $c->model("DBIC::Attachment")->find($att);
-    $c->detach('default') unless ( $c->stash->{att} );
-}
-
-sub defaultaction : PathPart('') Chained('attachment') Args(0) {
-    my ( $self, $c ) = @_;
-    $c->forward('view');
-}
-
 sub default : Private {
     my ( $self, $c ) = @_;
     $c->stash->{template} = 'message.tt';
@@ -132,50 +151,53 @@ sub default : Private {
     return ( $c->res->status(404) );
 }
 
+=head2 view
+
+Render the attachment in the browser (C<Content-Disposition: inline>), with
+caching for 1 day.
+
+=cut
 sub view : Chained('attachment') Args(0) {
     my ( $self, $c ) = @_;
-
-    return unless $c->check_view_permission;
+    my $att = $c->stash->{att};
+    $c->detach('unauthorized', ['view']) if not $c->check_view_permission;
 
     # avoid broken binary files
-    my $io_file = IO::File->new( $c->stash->{att}->filename )
+    my $io_file = IO::File->new( $att->filename )
         or $c->detach('default');
     $io_file->binmode;
 
     $c->res->output( $io_file );
-    $c->res->header( 'content-type', $c->stash->{att}->contenttype );
+    $c->res->header( 'content-type', $att->contenttype );
     $c->res->header(
-        "Content-Disposition" => "inline; filename=" . URI::Escape::uri_escape_utf8( $c->stash->{att}->name ) );
+        "Content-Disposition" => "inline; filename=" . URI::Escape::uri_escape_utf8( $att->name ) );
     $c->res->header( 'Cache-Control', 'max-age=86400, must-revalidate' );
 }
 
 =head2 download
 
-Force the attachment to be downloaded, through the use of
-content-disposition. No caching.
+Forwards to L</view> then forces the attachment to be downloaded
+(C<Content-Disposition: attachment>) and disables caching.
 
 =cut
 
 sub download : Chained('attachment') Args(0) {
     my ( $self, $c ) = @_;
-    my $att = $c->stash->{att};
-    return unless $c->check_view_permission;
     $c->forward('view');
-    $c->res->header( 'content-type', $att->contenttype );
-    $c->res->header( "Content-Disposition" => "attachment; filename=" . URI::Escape::uri_escape_utf8( $att->name ) );
+    $c->res->header( "Content-Disposition" => "attachment; filename=" . URI::Escape::uri_escape_utf8( $c->stash->{att}->name ) );
     $c->res->header( 'Cache-Control', 'no-cache' );
 
 }
 
 =head2 thumb
 
-thumb action for attachments. makes 100x100px thumbs
+Thumb action for attachments. Makes 100x100px thumbnails.
 
 =cut
 
 sub thumb : Chained('attachment') Args(0) {
     my ( $self, $c ) = @_;
-    return unless $c->check_view_permission;
+    $c->detach('unauthorized', ['view']) if not $c->check_view_permission;
     my $att = $c->stash->{att};
     my $photo;
     unless ( $photo = $att->photo ) {
@@ -193,7 +215,7 @@ sub thumb : Chained('attachment') Args(0) {
 
 }
 
-=head2  inline (private);
+=head2 inline
 
 Show 800x600 inline versions of photo attachments.
 
@@ -201,7 +223,7 @@ Show 800x600 inline versions of photo attachments.
 
 sub inline : Chained('attachment') Args(0) {
     my ( $self, $c ) = @_;
-    return unless $c->check_view_permission;
+    $c->detach('unauthorized', ['view']) if not $c->check_view_permission;
     my $att = $c->stash->{att};
     my $photo;
     unless ( $photo = $att->photo ) {
@@ -229,9 +251,9 @@ file system but delete its thumbnail and inline versions.
 
 sub delete : Chained('attachment') Args(0) {
     my ( $self, $c ) = @_;
-    return unless $c->forward('auth');
+    $c->detach('unauthorized', ['delete']) if not $c->forward('auth');
     $c->stash->{att}->delete();
-    $c->forward('/attachment/attachments');
+    $c->forward('attachments');
 }
 
 =head1 AUTHOR
@@ -241,7 +263,7 @@ Marcus Ramberg C<marcus@nordaaker.com>
 =head1 LICENSE
 
 This library is free software. You can redistribute it and/or modify
-it under the same terms as perl itself.
+it under the same terms as Perl itself.
 
 =cut
 
