@@ -16,9 +16,7 @@ Include files verbatim in your content, by writing {{<url>}}.
 
 =head1 METHODS
 
-=over 4
-
-=item format_content_order
+=head2 format_content_order
 
 Format order can be 1-99. The Include formatter runs on 6
 
@@ -26,9 +24,9 @@ Format order can be 1-99. The Include formatter runs on 6
 
 sub format_content_order { 6 }
 
-=item format_content
+=head2 format_content
 
-calls the formatter. Takes a ref to the content as well as the
+Calls the formatter. Takes a ref to the content as well as the
 context object.
 
 =cut
@@ -40,10 +38,10 @@ sub format_content {
     $$content =~ s|$re|$class->include( $c, $1 )|meg;
 }
 
-=item include <c> <url>
+=head2 include <c> <url>
 
-returns the content of url. Will store a cached version in
-$c->cache
+Returns the content of URL. Will store a cached version in
+C<< $c->cache >>.
 
 =cut
 
@@ -61,19 +59,18 @@ sub include {
     return $c->loc('Could not retrieve')." $url.\n";
 }
 
-=back
-
 =head1 SEE ALSO
 
-L<MojoMojo>,L<Module::Pluggable::Ordered>,L<URI::Fetch>
+L<MojoMojo>, L<Module::Pluggable::Ordered>, L<URI::Fetch>
 
 =head1 AUTHORS
 
 Marcus Ramberg <mramberg@cpan.org>
 
-=head1 License
+=head1 LICENSE
 
-This module is licensed under the same terms as Perl itself.
+This library is free software. You can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
 
