@@ -10,13 +10,13 @@ MojoMojo::Schema::Base::ResultSet
 
 =head1 DESCRIPTION
 
-Base class for all resultsets below MojoMojo::Schema::ResultSet::* namespace.
+Base class for all resultsets below the MojoMojo::Schema::ResultSet::* namespace.
 
 =head1 LICENSE
 
-This library is free software . You can redistribute it and/or modify 
-it under the same terms as perl itself.
+This library is free software. You can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
 
-1;
\ No newline at end of file
+1;
