@@ -355,4 +355,15 @@ sub store_links {
 
 sub encoded_body { return encode_entities_numeric( shift->body ); }
 
+=head1 AUTHOR
+
+Marcus Ramberg <mramberg@cpan.org>
+
+=head1 LICENSE
+
+This library is free software. You can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=cut
+
 1;
