@@ -56,6 +56,10 @@ __PACKAGE__->has_many(
 
 MojoMojo::Schema::Result::PageVersion
 
+=head1 AUTHOR
+
+Marcus Ramberg <mramberg@cpan.org>
+
 =head1 LICENSE
 
 This library is free software. You can redistribute it and/or modify
@@ -63,4 +67,5 @@ it under the same terms as Perl itself.
 
 =cut
 
+
 1;
