@@ -27,11 +27,16 @@ __PACKAGE__->utf8_columns(qw/name/);
 
 MojoMojo::Schema::Result::Role
 
+=head1 AUTHOR
+
+Marcus Ramberg <mramberg@cpan.org>
+
 =head1 LICENSE
 
-This library is free software . You can redistribute it and/or modify 
-it under the same terms as perl itself.
+This library is free software. You can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
 
+
 1;
