@@ -22,10 +22,14 @@ __PACKAGE__->belongs_to( "from_page", "MojoMojo::Schema::Result::Page", { id =>
 
 MojoMojo::Schema::Result::WantedPage
 
+=head1 AUTHOR
+
+Marcus Ramberg <mramberg@cpan.org>
+
 =head1 LICENSE
 
-This library is free software . You can redistribute it and/or modify 
-it under the same terms as perl itself.
+This library is free software. You can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
 
