@@ -3,29 +3,28 @@ use strict;
 use vars qw($VERSION);
 $VERSION = "1.3";
 
-
 # Configurable variables:
 my $smartypants_attr = "1";
-                    #  1 =>  "--" for em-dashes; no en-dash support
-                    #  2 =>  "---" for em-dashes; "--" for en-dashes
-                    #  3 =>  "--" for em-dashes; "---" for en-dashes
-                    #  See docs for more configuration options.
 
+#  1 =>  "--" for em-dashes; no en-dash support
+#  2 =>  "---" for em-dashes; "--" for en-dashes
+#  3 =>  "--" for em-dashes; "---" for en-dashes
+#  See docs for more configuration options.
 
 # Globals:
 my $tags_to_skip = qr!<(/?)(?:pre|code|kbd|script)[\s>]!;
 
 sub process {
-    shift if ($_[0] eq __PACKAGE__); # oops, called in OOP fashion.
+    shift if ( $_[0] eq __PACKAGE__ );    # oops, called in OOP fashion.
 
     # Paramaters:
-    my $text = shift;   # text to be parsed
+    my $text = shift;                     # text to be parsed
 
     # value of the smart_quotes="" attribute. Default to 'everything on'
     my $attr = shift || '1';
 
     # Options to specify which transformations to make:
-    my ($do_quotes, $do_backticks, $do_dashes, $do_ellipses, $do_stupefy);
+    my ( $do_quotes, $do_backticks, $do_dashes, $do_ellipses, $do_stupefy );
 
     # should we translate &quot; entities into normal quotes?
     my $convert_quot = 0;
@@ -35,7 +34,7 @@ sub process {
     # 1 : set all
     # 2 : set all, using old school en- and em- dash shortcuts
     # 3 : set all, using inverted old school en and em- dash shortcuts
-    # 
+    #
     # q : quotes
     # b : backtick quotes (``double'' only)
     # B : backtick quotes (``double'' and `single')
@@ -45,47 +44,53 @@ sub process {
     # e : ellipses
     # w : convert &quot; entities to " for Dreamweaver users
 
-    if ($attr eq "0") {
+    if ( $attr eq "0" ) {
+
         # Do nothing.
         return $text;
     }
-    elsif ($attr eq "1") {
+    elsif ( $attr eq "1" ) {
+
         # Do everything, turn all options on.
         $do_quotes    = 1;
         $do_backticks = 1;
         $do_dashes    = 1;
         $do_ellipses  = 1;
     }
-    elsif ($attr eq "2") {
+    elsif ( $attr eq "2" ) {
+
         # Do everything, turn all options on, use old school dash shorthand.
         $do_quotes    = 1;
         $do_backticks = 1;
         $do_dashes    = 2;
         $do_ellipses  = 1;
     }
-    elsif ($attr eq "3") {
+    elsif ( $attr eq "3" ) {
+
         # Do everything, turn all options on, use inverted old school dash shorthand.
         $do_quotes    = 1;
         $do_backticks = 1;
         $do_dashes    = 3;
         $do_ellipses  = 1;
     }
-    elsif ($attr eq "-1") {
+    elsif ( $attr eq "-1" ) {
+
         # Special "stupefy" mode.
-        $do_stupefy   = 1;
+        $do_stupefy = 1;
     }
     else {
-        my @chars = split(//, $attr);
+        my @chars = split( //, $attr );
         foreach my $c (@chars) {
-            if    ($c eq "q") { $do_quotes    = 1; }
-            elsif ($c eq "b") { $do_backticks = 1; }
-            elsif ($c eq "B") { $do_backticks = 2; }
-            elsif ($c eq "d") { $do_dashes    = 1; }
-            elsif ($c eq "D") { $do_dashes    = 2; }
-            elsif ($c eq "i") { $do_dashes    = 3; }
-            elsif ($c eq "e") { $do_ellipses  = 1; }
-            elsif ($c eq "w") { $convert_quot = 1; }
+            if    ( $c eq "q" ) { $do_quotes    = 1; }
+            elsif ( $c eq "b" ) { $do_backticks = 1; }
+            elsif ( $c eq "B" ) { $do_backticks = 2; }
+            elsif ( $c eq "d" ) { $do_dashes    = 1; }
+            elsif ( $c eq "D" ) { $do_dashes    = 2; }
+            elsif ( $c eq "i" ) { $do_dashes    = 3; }
+            elsif ( $c eq "e" ) { $do_ellipses  = 1; }
+            elsif ( $c eq "w" ) { $convert_quot = 1; }
             else {
+
                 # Unknown attribute option, ignore.
             }
         }
@@ -93,26 +98,29 @@ sub process {
 
     my $tokens ||= _tokenize($text);
     my $result = '';
-    my $in_pre = 0;  # Keep track of when we're inside <pre> or <code> tags.
+    my $in_pre = 0;    # Keep track of when we're inside <pre> or <code> tags.
 
-    my $prev_token_last_char = "";  # This is a cheat, used to get some context
-                                    # for one-character tokens that consist of 
-                                    # just a quote char. What we do is remember
-                                    # the last character of the previous text
-                                    # token, to use as context to curl single-
-                                    # character quote tokens correctly.
+    my $prev_token_last_char = "";    # This is a cheat, used to get some context
+                                      # for one-character tokens that consist of
+                                      # just a quote char. What we do is remember
+                                      # the last character of the previous text
+                                      # token, to use as context to curl single-
+                                      # character quote tokens correctly.
 
     foreach my $cur_token (@$tokens) {
-        if ($cur_token->[0] eq "tag") {
+        if ( $cur_token->[0] eq "tag" ) {
+
             # Don't mess with quotes inside tags.
             $result .= $cur_token->[1];
-            if ($cur_token->[1] =~ m/$tags_to_skip/) {
+            if ( $cur_token->[1] =~ m/$tags_to_skip/ ) {
                 $in_pre = defined $1 && $1 eq '/' ? 0 : 1;
             }
-        } else {
+        }
+        else {
             my $t = $cur_token->[1];
-            my $last_char = substr($t, -1); # Remember last char of this token before processing.
-            if (! $in_pre) {
+            my $last_char =
+                substr( $t, -1 );    # Remember last char of this token before processing.
+            if ( !$in_pre ) {
                 $t = ProcessEscapes($t);
 
                 if ($convert_quot) {
@@ -120,9 +128,9 @@ sub process {
                 }
 
                 if ($do_dashes) {
-                    $t = EducateDashes($t)                  if ($do_dashes == 1);
-                    $t = EducateDashesOldSchool($t)         if ($do_dashes == 2);
-                    $t = EducateDashesOldSchoolInverted($t) if ($do_dashes == 3);
+                    $t = EducateDashes($t)                  if ( $do_dashes == 1 );
+                    $t = EducateDashesOldSchool($t)         if ( $do_dashes == 2 );
+                    $t = EducateDashesOldSchoolInverted($t) if ( $do_dashes == 3 );
                 }
 
                 $t = EducateEllipses($t) if $do_ellipses;
@@ -130,22 +138,24 @@ sub process {
                 # Notes: backticks need to be processed before quotes.
                 if ($do_backticks) {
                     $t = EducateBackticks($t);
-                    $t = EducateSingleBackticks($t) if ($do_backticks == 2);
+                    $t = EducateSingleBackticks($t) if ( $do_backticks == 2 );
                 }
 
                 if ($do_quotes) {
-                    if ($t eq q/'/) {
+                    if ( $t eq q/'/ ) {
+
                         # Special case: single-character ' token
-                        if ($prev_token_last_char =~ m/\S/) {
+                        if ( $prev_token_last_char =~ m/\S/ ) {
                             $t = "&#8217;";
                         }
                         else {
                             $t = "&#8216;";
                         }
                     }
-                    elsif ($t eq q/"/) {
+                    elsif ( $t eq q/"/ ) {
+
                         # Special case: single-character " token
-                        if ($prev_token_last_char =~ m/\S/) {
+                        if ( $prev_token_last_char =~ m/\S/ ) {
                             $t = "&#8221;";
                         }
                         else {
@@ -153,7 +163,8 @@ sub process {
                         }
                     }
                     else {
-                        # Normal case:                  
+
+                        # Normal case:
                         $t = EducateQuotes($t);
                     }
                 }
@@ -168,19 +179,21 @@ sub process {
     return $result;
 }
 
-
 sub SmartQuotes {
+
     # Paramaters:
-    my $text = shift;   # text to be parsed
-    my $attr = shift;   # value of the smart_quotes="" attribute
+    my $text = shift;    # text to be parsed
+    my $attr = shift;    # value of the smart_quotes="" attribute
 
-    my $do_backticks;   # should we educate ``backticks'' -style quotes?
+    my $do_backticks;    # should we educate ``backticks'' -style quotes?
+
+    if ( $attr == 0 ) {
 
-    if ($attr == 0) {
         # do nothing;
         return $text;
     }
-    elsif ($attr == 2) {
+    elsif ( $attr == 2 ) {
+
         # smarten ``backticks'' -style quotes
         $do_backticks = 1;
     }
@@ -192,50 +205,55 @@ sub SmartQuotes {
     # an HTML tag. Add a space to give the quote education algorithm a bit of
     # context, so that it can guess correctly that it's a closing quote:
     my $add_extra_space = 0;
-    if ($text =~ m/>['"]\z/) {
-        $add_extra_space = 1; # Remember, so we can trim the extra space later.
+    if ( $text =~ m/>['"]\z/ ) {
+        $add_extra_space = 1;    # Remember, so we can trim the extra space later.
         $text .= " ";
     }
 
     my $tokens ||= _tokenize($text);
     my $result = '';
-    my $in_pre = 0;  # Keep track of when we're inside <pre> or <code> tags
+    my $in_pre = 0;              # Keep track of when we're inside <pre> or <code> tags
 
-    my $prev_token_last_char = "";  # This is a cheat, used to get some context
-                                    # for one-character tokens that consist of 
-                                    # just a quote char. What we do is remember
-                                    # the last character of the previous text
-                                    # token, to use as context to curl single-
-                                    # character quote tokens correctly.
+    my $prev_token_last_char = "";    # This is a cheat, used to get some context
+                                      # for one-character tokens that consist of
+                                      # just a quote char. What we do is remember
+                                      # the last character of the previous text
+                                      # token, to use as context to curl single-
+                                      # character quote tokens correctly.
 
     foreach my $cur_token (@$tokens) {
-        if ($cur_token->[0] eq "tag") {
+        if ( $cur_token->[0] eq "tag" ) {
+
             # Don't mess with quotes inside tags
             $result .= $cur_token->[1];
-            if ($cur_token->[1] =~ m/$tags_to_skip/) {
+            if ( $cur_token->[1] =~ m/$tags_to_skip/ ) {
                 $in_pre = defined $1 && $1 eq '/' ? 0 : 1;
             }
-        } else {
+        }
+        else {
             my $t = $cur_token->[1];
-            my $last_char = substr($t, -1); # Remember last char of this token before processing.
-            if (! $in_pre) {
+            my $last_char =
+                substr( $t, -1 );    # Remember last char of this token before processing.
+            if ( !$in_pre ) {
                 $t = ProcessEscapes($t);
                 if ($do_backticks) {
                     $t = EducateBackticks($t);
                 }
 
-                if ($t eq q/'/) {
+                if ( $t eq q/'/ ) {
+
                     # Special case: single-character ' token
-                    if ($prev_token_last_char =~ m/\S/) {
+                    if ( $prev_token_last_char =~ m/\S/ ) {
                         $t = "&#8217;";
                     }
                     else {
                         $t = "&#8216;";
                     }
                 }
-                elsif ($t eq q/"/) {
+                elsif ( $t eq q/"/ ) {
+
                     # Special case: single-character " token
-                    if ($prev_token_last_char =~ m/\S/) {
+                    if ( $prev_token_last_char =~ m/\S/ ) {
                         $t = "&#8221;";
                     }
                     else {
@@ -243,7 +261,8 @@ sub SmartQuotes {
                     }
                 }
                 else {
-                    # Normal case:                  
+
+                    # Normal case:
                     $t = EducateQuotes($t);
                 }
 
@@ -254,48 +273,53 @@ sub SmartQuotes {
     }
 
     if ($add_extra_space) {
-        $result =~ s/ \z//;  # Trim trailing space if we added one earlier.
+        $result =~ s/ \z//;    # Trim trailing space if we added one earlier.
     }
     return $result;
 }
 
-
 sub SmartDashes {
+
     # Paramaters:
-    my $text = shift;   # text to be parsed
-    my $attr = shift;   # value of the smart_dashes="" attribute
+    my $text = shift;          # text to be parsed
+    my $attr = shift;          # value of the smart_dashes="" attribute
 
     # reference to the subroutine to use for dash education, default to EducateDashes:
     my $dash_sub_ref = \&EducateDashes;
 
-    if ($attr == 0) {
+    if ( $attr == 0 ) {
+
         # do nothing;
         return $text;
     }
-    elsif ($attr == 2) {
+    elsif ( $attr == 2 ) {
+
         # use old smart dash shortcuts, "--" for en, "---" for em
-        $dash_sub_ref = \&EducateDashesOldSchool; 
+        $dash_sub_ref = \&EducateDashesOldSchool;
     }
-    elsif ($attr == 3) {
+    elsif ( $attr == 3 ) {
+
         # inverse of 2, "--" for em, "---" for en
-        $dash_sub_ref = \&EducateDashesOldSchoolInverted; 
+        $dash_sub_ref = \&EducateDashesOldSchoolInverted;
     }
 
     my $tokens;
     $tokens ||= _tokenize($text);
 
     my $result = '';
-    my $in_pre = 0;  # Keep track of when we're inside <pre> or <code> tags
+    my $in_pre = 0;    # Keep track of when we're inside <pre> or <code> tags
     foreach my $cur_token (@$tokens) {
-        if ($cur_token->[0] eq "tag") {
+        if ( $cur_token->[0] eq "tag" ) {
+
             # Don't mess with quotes inside tags
             $result .= $cur_token->[1];
-            if ($cur_token->[1] =~ m/$tags_to_skip/) {
+            if ( $cur_token->[1] =~ m/$tags_to_skip/ ) {
                 $in_pre = defined $1 && $1 eq '/' ? 0 : 1;
             }
-        } else {
+        }
+        else {
             my $t = $cur_token->[1];
-            if (! $in_pre) {
+            if ( !$in_pre ) {
                 $t = ProcessEscapes($t);
                 $t = $dash_sub_ref->($t);
             }
@@ -305,13 +329,14 @@ sub SmartDashes {
     return $result;
 }
 
-
 sub SmartEllipses {
-    # Paramaters:
-    my $text = shift;   # text to be parsed
-    my $attr = shift;   # value of the smart_ellipses="" attribute
 
-    if ($attr == 0) {
+    # Paramaters:
+    my $text = shift;    # text to be parsed
+    my $attr = shift;    # value of the smart_ellipses="" attribute
+
+    if ( $attr == 0 ) {
+
         # do nothing;
         return $text;
     }
@@ -320,17 +345,19 @@ sub SmartEllipses {
     $tokens ||= _tokenize($text);
 
     my $result = '';
-    my $in_pre = 0;  # Keep track of when we're inside <pre> or <code> tags
+    my $in_pre = 0;      # Keep track of when we're inside <pre> or <code> tags
     foreach my $cur_token (@$tokens) {
-        if ($cur_token->[0] eq "tag") {
+        if ( $cur_token->[0] eq "tag" ) {
+
             # Don't mess with quotes inside tags
             $result .= $cur_token->[1];
-            if ($cur_token->[1] =~ m/$tags_to_skip/) {
+            if ( $cur_token->[1] =~ m/$tags_to_skip/ ) {
                 $in_pre = defined $1 && $1 eq '/' ? 0 : 1;
             }
-        } else {
+        }
+        else {
             my $t = $cur_token->[1];
-            if (! $in_pre) {
+            if ( !$in_pre ) {
                 $t = ProcessEscapes($t);
                 $t = EducateEllipses($t);
             }
@@ -340,16 +367,16 @@ sub SmartEllipses {
     return $result;
 }
 
-
 sub EducateQuotes {
-#
-#   Parameter:  String.
-#
-#   Returns:    The string, with "educated" curly quote HTML entities.
-#
-#   Example input:  "Isn't this fun?"
-#   Example output: &#8220;Isn&#8217;t this fun?&#8221;
-#
+
+    #
+    #   Parameter:  String.
+    #
+    #   Returns:    The string, with "educated" curly quote HTML entities.
+    #
+    #   Example input:  "Isn't this fun?"
+    #   Example output: &#8220;Isn&#8217;t this fun?&#8221;
+    #
 
     local $_ = shift;
 
@@ -358,7 +385,6 @@ sub EducateQuotes {
     # for compatibility with Perl 5.005:
     local $^W = 0;
 
-
     # Make our own "punctuation" character class, because the POSIX-style
     # [:PUNCT:] is only available in Perl 5.6 or later:
     my $punct_class = qr/[!"#\$\%'()*+,-.\/:;<=>?\@\[\\\]\^_`{|}~]/;
@@ -368,13 +394,11 @@ sub EducateQuotes {
     s/^'(?=$punct_class\B)/&#8217;/;
     s/^"(?=$punct_class\B)/&#8221;/;
 
-
     # Special case for double sets of quotes, e.g.:
     #   <p>He said, "'Quoted' words in a larger quote."</p>
     s/"'(?=\w)/&#8220;&#8216;/g;
     s/'"(?=\w)/&#8216;&#8220;/g;
 
-
     my $close_class = qr![^\ \t\r\n\[\{\(]!;
 
     # Single closing quotes:
@@ -405,16 +429,16 @@ sub EducateQuotes {
     return $_;
 }
 
-
 sub EducateBackticks {
-#
-#   Parameter:  String.
-#   Returns:    The string, with ``backticks'' -style double quotes
-#               translated into HTML curly quote entities.
-#
-#   Example input:  ``Isn't this fun?''
-#   Example output: &#8220;Isn't this fun?&#8221;
-#
+
+    #
+    #   Parameter:  String.
+    #   Returns:    The string, with ``backticks'' -style double quotes
+    #               translated into HTML curly quote entities.
+    #
+    #   Example input:  ``Isn't this fun?''
+    #   Example output: &#8220;Isn't this fun?&#8221;
+    #
 
     local $_ = shift;
     s/``/&#8220;/g;
@@ -422,16 +446,16 @@ sub EducateBackticks {
     return $_;
 }
 
-
 sub EducateSingleBackticks {
-#
-#   Parameter:  String.
-#   Returns:    The string, with `backticks' -style single quotes
-#               translated into HTML curly quote entities.
-#
-#   Example input:  `Isn't this fun?'
-#   Example output: &#8216;Isn&#8217;t this fun?&#8217;
-#
+
+    #
+    #   Parameter:  String.
+    #   Returns:    The string, with `backticks' -style single quotes
+    #               translated into HTML curly quote entities.
+    #
+    #   Example input:  `Isn't this fun?'
+    #   Example output: &#8216;Isn&#8217;t this fun?&#8217;
+    #
 
     local $_ = shift;
     s/`/&#8216;/g;
@@ -439,29 +463,29 @@ sub EducateSingleBackticks {
     return $_;
 }
 
-
 sub EducateDashes {
-#
-#   Parameter:  String.
-#
-#   Returns:    The string, with each instance of "--" translated to
-#               an em-dash HTML entity.
-#
+
+    #
+    #   Parameter:  String.
+    #
+    #   Returns:    The string, with each instance of "--" translated to
+    #               an em-dash HTML entity.
+    #
 
     local $_ = shift;
     s/--/&#8212;/g;
     return $_;
 }
 
-
 sub EducateDashesOldSchool {
-#
-#   Parameter:  String.
-#
-#   Returns:    The string, with each instance of "--" translated to
-#               an en-dash HTML entity, and each "---" translated to
-#               an em-dash HTML entity.
-#
+
+    #
+    #   Parameter:  String.
+    #
+    #   Returns:    The string, with each instance of "--" translated to
+    #               an en-dash HTML entity, and each "---" translated to
+    #               an em-dash HTML entity.
+    #
 
     local $_ = shift;
     s/---/&#8212;/g;    # em
@@ -469,22 +493,22 @@ sub EducateDashesOldSchool {
     return $_;
 }
 
-
 sub EducateDashesOldSchoolInverted {
-#
-#   Parameter:  String.
-#
-#   Returns:    The string, with each instance of "--" translated to
-#               an em-dash HTML entity, and each "---" translated to
-#               an en-dash HTML entity. Two reasons why: First, unlike the
-#               en- and em-dash syntax supported by
-#               EducateDashesOldSchool(), it's compatible with existing
-#               entries written before SmartyPants 1.1, back when "--" was
-#               only used for em-dashes.  Second, em-dashes are more
-#               common than en-dashes, and so it sort of makes sense that
-#               the shortcut should be shorter to type. (Thanks to Aaron
-#               Swartz for the idea.)
-#
+
+    #
+    #   Parameter:  String.
+    #
+    #   Returns:    The string, with each instance of "--" translated to
+    #               an em-dash HTML entity, and each "---" translated to
+    #               an en-dash HTML entity. Two reasons why: First, unlike the
+    #               en- and em-dash syntax supported by
+    #               EducateDashesOldSchool(), it's compatible with existing
+    #               entries written before SmartyPants 1.1, back when "--" was
+    #               only used for em-dashes.  Second, em-dashes are more
+    #               common than en-dashes, and so it sort of makes sense that
+    #               the shortcut should be shorter to type. (Thanks to Aaron
+    #               Swartz for the idea.)
+    #
 
     local $_ = shift;
     s/---/&#8211;/g;    # en
@@ -492,71 +516,70 @@ sub EducateDashesOldSchoolInverted {
     return $_;
 }
 
-
 sub EducateEllipses {
-#
-#   Parameter:  String.
-#   Returns:    The string, with each instance of "..." translated to
-#               an ellipsis HTML entity.
-#
-#   Example input:  Huh...?
-#   Example output: Huh&#8230;?
-#
+
+    #
+    #   Parameter:  String.
+    #   Returns:    The string, with each instance of "..." translated to
+    #               an ellipsis HTML entity.
+    #
+    #   Example input:  Huh...?
+    #   Example output: Huh&#8230;?
+    #
 
     local $_ = shift;
     s/\.\.\./&#8230;/g;
     return $_;
 }
 
-
 sub StupefyEntities {
-#
-#   Parameter:  String.
-#   Returns:    The string, with each SmartyPants HTML entity translated to
-#               its ASCII counterpart.
-#
-#   Example input:  &#8220;Hello &#8212; world.&#8221;
-#   Example output: "Hello -- world."
-#
+
+    #
+    #   Parameter:  String.
+    #   Returns:    The string, with each SmartyPants HTML entity translated to
+    #               its ASCII counterpart.
+    #
+    #   Example input:  &#8220;Hello &#8212; world.&#8221;
+    #   Example output: "Hello -- world."
+    #
 
     local $_ = shift;
 
-    s/&#8211;/-/g;      # en-dash
-    s/&#8212;/--/g;     # em-dash
+    s/&#8211;/-/g;     # en-dash
+    s/&#8212;/--/g;    # em-dash
 
-    s/&#8216;/'/g;      # open single quote
-    s/&#8217;/'/g;      # close single quote
+    s/&#8216;/'/g;     # open single quote
+    s/&#8217;/'/g;     # close single quote
 
-    s/&#8220;/"/g;      # open double quote
-    s/&#8221;/"/g;      # close double quote
+    s/&#8220;/"/g;     # open double quote
+    s/&#8221;/"/g;     # close double quote
 
-    s/&#8230;/.../g;    # ellipsis
+    s/&#8230;/.../g;   # ellipsis
 
     return $_;
 }
 
-
 sub SmartyPantsVersion {
     return $VERSION;
 }
 
-
 sub ProcessEscapes {
-#
-#   Parameter:  String.
-#   Returns:    The string, with after processing the following backslash
-#               escape sequences. This is useful if you want to force a "dumb"
-#               quote or other character to appear.
-#
-#               Escape  Value
-#               ------  -----
-#               \\      &#92;
-#               \"      &#34;
-#               \'      &#39;
-#               \.      &#46;
-#               \-      &#45;
-#               \`      &#96;
-#
+
+    #
+    #   Parameter:  String.
+    #   Returns:    The string, with after processing the following backslash
+    #               escape sequences. This is useful if you want to force a "dumb"
+    #               quote or other character to appear.
+    #
+    #               Escape  Value
+    #               ------  -----
+    #               \\      &#92;
+    #               \"      &#34;
+    #               \'      &#39;
+    #               \.      &#46;
+    #               \-      &#45;
+    #               \`      &#96;
+    #
     local $_ = shift;
 
     s! \\\\ !&#92;!gx;
@@ -569,21 +592,21 @@ sub ProcessEscapes {
     return $_;
 }
 
-
 sub _tokenize {
-#
-#   Parameter:  String containing HTML markup.
-#   Returns:    Reference to an array of the tokens comprising the input
-#               string. Each token is either a tag (possibly with nested,
-#               tags contained therein, such as <a href="<MTFoo>">, or a
-#               run of text between tags. Each element of the array is a
-#               two-element array; the first is either 'tag' or 'text';
-#               the second is the actual value.
-#
-#
-#   Based on the _tokenize() subroutine from Brad Choate's MTRegex plugin.
-#       <http://www.bradchoate.com/past/mtregex.php>
-#
+
+    #
+    #   Parameter:  String containing HTML markup.
+    #   Returns:    Reference to an array of the tokens comprising the input
+    #               string. Each token is either a tag (possibly with nested,
+    #               tags contained therein, such as <a href="<MTFoo>">, or a
+    #               run of text between tags. Each element of the array is a
+    #               two-element array; the first is either 'tag' or 'text';
+    #               the second is the actual value.
+    #
+    #
+    #   Based on the _tokenize() subroutine from Brad Choate's MTRegex plugin.
+    #       <http://www.bradchoate.com/past/mtregex.php>
+    #
 
     my $str = shift;
 
@@ -594,21 +617,20 @@ sub _tokenize {
     # pattern to match balanced nested <> pairs, up to two levels deep:
     my $nested_angles = qr/<(?:[^<>]|<[^<>]*>)*>/;
 
-    while ($str =~ m/($nested_angles)/gs) {
+    while ( $str =~ m/($nested_angles)/gs ) {
         my $whole_tag = $1;
         my $sec_start = pos $str;
         my $tag_start = $sec_start - length $whole_tag;
-        if ($pos < $tag_start) {
-            push @tokens, ['text', substr($str, $pos, $tag_start - $pos)];
+        if ( $pos < $tag_start ) {
+            push @tokens, [ 'text', substr( $str, $pos, $tag_start - $pos ) ];
         }
-        push @tokens, ['tag', $whole_tag];
+        push @tokens, [ 'tag', $whole_tag ];
         $pos = pos $str;
     }
-    push @tokens, ['text', substr($str, $pos, $len - $pos)] if $pos < $len;
+    push @tokens, [ 'text', substr( $str, $pos, $len - $pos ) ] if $pos < $len;
     \@tokens;
 }
 
-
 1;
 __END__
 
