@@ -13,13 +13,13 @@ if (window['loadFirebugConsole']) {
 
 MojoMojo.PermissionsEditor = function(params) {
     var container = $(params.container);
-    
+
     var API = {
         clear_permissions: function (link) {
           var span = link.parentNode;
           var td   = span.parentNode;
           var row  = td.parentNode;
-          
+
           var role_name = $(td).find('input').get(0).value;
 
           $.ajax({
@@ -31,7 +31,7 @@ MojoMojo.PermissionsEditor = function(params) {
               $(td).find('span, span a').addClass('hide');
             }
           });
-          
+
           return false;
         },
         enable_edit: function (link) {
@@ -44,9 +44,9 @@ MojoMojo.PermissionsEditor = function(params) {
         save_changes: function (link) {
           var td  = link.parentNode;
           var row = td.parentNode;
-          
+
           var values = [];
-          $(row).find('input').map( function(i, elt) { 
+          $(row).find('input').map( function(i, elt) {
             if (elt.type == 'checkbox')
               values.push(elt.name + "=" + (elt.checked ? "1" : "0"));
             else
@@ -62,7 +62,7 @@ MojoMojo.PermissionsEditor = function(params) {
               $(td).find('a,span').toggleClass('hide');
             }
           });
-          
+
           return false;
         }
     };
@@ -85,7 +85,7 @@ MojoMojo.RoleForm = function(params) {
           var li   = link.parentNode;
           var list = li.parentNode;
           list.removeChild(li);
-          
+
           var remaining = list.getElementsByTagName('li');
           if (remaining.length == 1) {
             $(remaining[0]).removeClass('hide');
@@ -117,14 +117,14 @@ MojoMojo.RoleForm = function(params) {
 
             $(document).ready(function() {
               member_input.autocomplete(
-                params.user_search_url, 
-                { 
-                  minChars:      1, 
-                  matchSubset:   1, 
-                  matchContains: 1, 
-                  cacheLength:   10, 
+                params.user_search_url,
+                {
+                  minChars:      1,
+                  matchSubset:   1,
+                  matchContains: 1,
+                  cacheLength:   10,
                   formatItem:    format_item,
-                  selectOnly:    1 
+                  selectOnly:    1
                 }
               ).result(select_item);
             });
@@ -145,7 +145,7 @@ function oneshot() {
         clearTimeout( timer );
         timer = setTimeout( fun, time );
     };
-} 
+}
 var oneshot_preview = oneshot();
 var oneshot_pause = 1000;  // Time in milliseconds.
 var on_change_refresh_rate = 10000;
@@ -158,13 +158,13 @@ $( function() {
     setupToggleMaximized();
 
     $('.fade').each(function() { doBGFade(this,[255,255,100],[255,255,255],'transparent',75,20,4); })
-    
+
     $('.toggleInfo').click(function() {
         $('#hidden_info').toggle();
         return false;
     });
     $('#body').each(function() { this.focus(); })
-    $('#body').keyup(function() { 
+    $('#body').keyup(function() {
        fetch_preview.only_every(on_change_refresh_rate);
        oneshot_preview(fetch_preview, oneshot_pause);
     });
@@ -176,13 +176,13 @@ $( function() {
         target:'#tags',
         beforeSubmit: function() {
             $('#addtag').hide();
-            $('#showtag').show();            
+            $('#showtag').show();
         },
         success: function() {
             $('#taginput').attr('value','')
         }
     })
-    
+
     $('#commentlogin').livequery (function() {
          $('#commentlogin').ajaxForm({
         target: '#commentLogin'
@@ -201,7 +201,7 @@ $( function() {
         target=$(this).parents('.item').find('.diff');
         if (!target.html()) {
             target.load( $(this).attr('href') );
-        } 
+        }
         target.toggle();
         return false;
     });
@@ -216,22 +216,22 @@ $( function() {
             button_image_url: $.uri_for("/.static/gfx/uploadbutton.png"),
             button_width: 61,
             button_height: 22,
-            flash_url : $.uri_for('/.static/flash/swfupload.swf'),
+            flash_url: $.uri_for('/.static/flash/swfupload.swf'),
             upload_url: $('#upload_link').attr('href'),	// Relative to the SWF file
-            file_size_limit : "100 MB",
+            file_size_limit: "100 MB",
             file_post_name: 'file' ,
-            file_types : "*",
-            file_types_description : "Any files",
-            file_dialog_complete_handler : function(numFilesSelected, numFilesQueued) {
+            file_types: "*",
+            file_types_description: "Any files",
+            file_dialog_complete_handler: function(numFilesSelected, numFilesQueued) {
                     this.startUpload();
             },
-            upload_start_handler : function(file) {
+            upload_start_handler: function(file) {
                 $('#progress').width('0')
                 $('#progress_status').html(file.name+' 0% ' + loc('done') );
                 $('#progressbar').show();$('#progress_status').show();
                 return true;
             },
-            upload_progress_handler : function(file, bytesLoaded, bytesTotal) {
+            upload_progress_handler: function(file, bytesLoaded, bytesTotal) {
                 if ( $('#progressbar').is(':hidden') ){
                   $('#progress').width('0');
                   $('#progress_status').html(file.name+' 0% ' + loc('done') );
@@ -245,20 +245,20 @@ $( function() {
                     this.debug(ex);
                 }
             },
-            queue_complete_handler : function(numfiles) {
+            queue_complete_handler: function(numfiles) {
                 $('#progressbar').hide();$('#progress_status').hide();
-                $('#attachments').load($('#list_link').attr('href'))  
-            } 
+                $('#attachments').load($('#list_link').attr('href'))
+            }
         })
     }).click(function() { uploader.selectFiles() })
     $('.delete_attachment').click(function() {
         link=$(this)
         $.post(link.attr('href'),function() {
-            link.parents('p').remove();
+            link.parents('tr').remove();
         })
         return false;
     })
-    
+
     new MojoMojo.PermissionsEditor({
         container: '#permissions_editor',
         selectors: {
@@ -310,7 +310,7 @@ var fetch_preview = function() {
             console.log("Failed to submit");
             $('#editspinner').hide();
         },
-        success: function(r) { 
+        success: function(r) {
             $('#content_preview').html(r);
             $('#editspinner').hide();
         }
@@ -383,7 +383,7 @@ function insertTags(txtarea,tagOpen, tagClose, sampleText) {
 
     txtarea = document.getElementById(txtarea);
     var theSelection;
-    
+
     // IE / Opera
     if(document.selection && document.selection.createRange) {
         theSelection = document.selection.createRange().text;
@@ -455,11 +455,11 @@ Function.prototype.only_every = function (millisecond_delay) {
 };
 
 // jQuery extensions
-jQuery.prototype.any = function(callback) { 
+jQuery.prototype.any = function(callback) {
     return (this.filter(callback).length > 0)
 }
 
-setupToggleMaximized = function() { 
+setupToggleMaximized = function() {
     var $img    = $('<img id="maximize"/>');
     var max     = $("#container").hasClass('maximized-container');
     var img_uri = $.uri_for("/.static/gfx/maximize_width_X.png");
@@ -518,6 +518,6 @@ menuInsertChildren = function(node) {
         asynchronous: true,
         insertion: Insertion.Bottom
     });
-  
+
     node.setAttribute("class", "menuParent");
 };
